@@ -7,6 +7,8 @@ use mars_raw_utils::{
     util
 };
 
+use rayon::prelude::*;
+
 #[macro_use]
 extern crate clap;
 use clap::{Arg, App};
@@ -53,6 +55,14 @@ fn main() {
                     .arg(Arg::with_name(constants::param::PARAM_ONLY_NEW)
                         .short(constants::param::PARAM_ONLY_NEW_SHORT)
                         .help("Only new images. Skipped processed images."))
+                    .arg(Arg::with_name(constants::param::PARAM_CAL_PROFILE)
+                        .short(constants::param::PARAM_CAL_PROFILE_SHORT)
+                        .long(constants::param::PARAM_CAL_PROFILE)
+                        .value_name("PARAM_CAL_PROFILE")
+                        .help("Calibration profile file path")
+                        .required(false)
+                        .multiple(true)
+                        .takes_value(true)) 
                     .get_matches();
 
     if matches.is_present(constants::param::PARAM_VERBOSE) {
@@ -67,6 +77,7 @@ fn main() {
     let mut red_scalar = constants::DEFAULT_RED_WEIGHT;
     let mut green_scalar = constants::DEFAULT_GREEN_WEIGHT;
     let mut blue_scalar = constants::DEFAULT_BLUE_WEIGHT;
+    let filename_suffix: String = String::from(constants::OUTPUT_FILENAME_APPEND);
 
     // Check formatting and handle it
     if matches.is_present(constants::param::PARAM_RED_WEIGHT) {
@@ -99,14 +110,20 @@ fn main() {
         }
     }
 
+    let profiles: Vec<&str> = match matches.values_of(constants::param::PARAM_CAL_PROFILE) {
+        Some(profiles) => profiles.collect(),
+        None => vec!()
+    };
+
     let input_files: Vec<&str> = matches.values_of(constants::param::PARAM_INPUTS).unwrap().collect();
 
-    for in_file in input_files.iter() {
+    let num_files = input_files.len();
+    input_files.into_par_iter().enumerate().for_each(|(idx, in_file)| {
         if path::file_exists(in_file) {
-            vprintln!("Processing File: {}", in_file);
-            m20::helirte::process_file(in_file, red_scalar, green_scalar, blue_scalar, only_new);
+            vprintln!("Processing File: {} (#{} of {})", in_file, idx, num_files);
+            m20::helirte::process_with_profiles(in_file, red_scalar, green_scalar, blue_scalar, only_new, &filename_suffix, &profiles);
         } else {
             eprintln!("File not found: {}", in_file);
         }
-    }
+    });
 }
