@@ -7,8 +7,11 @@ pub const OUTPUT_FILENAME_APPEND : &str = "rjcal";
 
 pub mod url {
     pub const MSL_RAW_WEBSERVICE_URL : &str = "https://mars.nasa.gov/api/v1/raw_image_items/";
+    pub const MSL_LATEST_WEBSERVICE_URL : &str = "https://mars.nasa.gov/api/v1/raw_image_items/msl/latest/";
     pub const M20_RAW_WEBSERVICE_URL : &str = "https://mars.nasa.gov/rss/api/";
+    pub const M20_LATEST_WEBSERVICE_URL : &str = "https://mars.nasa.gov/rss/api/?feed=raw_images&category=mars2020,ingenuity&feedtype=json&ver=1.2&latest=true";
     pub const NSYT_RAW_WEBSERVICE_URL : &str = "https://mars.nasa.gov/api/v1/raw_image_items/";
+    pub const NSYT_LATEST_WEBSERVICE_URL : &str = "https://mars.nasa.gov/api/v1/raw_image_items/insight/latest/";
 }
 
 pub mod time {
@@ -77,6 +80,9 @@ pub mod param {
     pub const PARAM_COLOR_NOISE_REDUCTION : &str = "color_noise_reduction";
     pub const PARAM_COLOR_NOISE_REDUCTION_SHORT : &str = "c";
 
+    pub const PARAM_CAL_PROFILE : &str = "profile";
+    pub const PARAM_CAL_PROFILE_SHORT : &str = "P";
+
     // Don't apply ILT
     pub const PARAM_RAW_COLOR : &str = "raw";
     pub const PARAM_RAW_COLOR_SHORT : &str = "r";
@@ -94,4 +100,27 @@ pub mod param {
 
     pub const PARAM_SCALE_FACTOR : &str = "factor";
     pub const PARAM_SCALE_FACTOR_SHORT : &str = "f";
+
+    pub const PARAM_LEVELS_WHITE_LEVEL : &str = "whitelevel";
+    pub const PARAM_LEVELS_WHITE_LEVEL_SHORT : &str = "w";
+
+    pub const PARAM_LEVELS_BLACK_LEVEL : &str = "blacklevel";
+    pub const PARAM_LEVELS_BLACK_LEVEL_SHORT : &str = "b";
+
+    pub const PARAM_GAMMA : &str = "gamma";
+    pub const PARAM_GAMMA_SHORT : &str = "g";
+
+    pub const PARAM_DELAY : &str = "delay";
+    pub const PARAM_DELAY_SHORT : &str = "d";
+    
+    pub const PARAM_LOWPASS : &str = "lowpass";
+    pub const PARAM_LOWPASS_SHORT : &str = "l";
+
+    pub const PARAM_PRODUCT_TYPE : &str = "prodtype";
+    pub const PARAM_PRODUCT_TYPE_SHORT : &str = "p";
+
+    pub const PARAM_QUALITY_WINDOW_SIZE : &str = "window";
+    pub const PARAM_QUALITY_WINDOW_SIZE_SHORT : &str = "w";
 }
+
+
