@@ -1,14 +1,14 @@
 
 use crate::{
-        rgbimage::RgbImage, 
         error, 
         enums,
-        calibfile
+        calibfile,
+        image::MarsImage
 };
 
-pub fn load_flat(instrument:enums::Instrument) -> error::Result<RgbImage> {
+pub fn load_flat(instrument:enums::Instrument) -> error::Result<MarsImage> {
     match calibfile::get_calibration_file_for_instrument(instrument, enums::CalFileType::FlatField) {
-        Ok(cal_file) => RgbImage::open(cal_file, instrument),
+        Ok(cal_file) => Ok(MarsImage::open(cal_file, instrument)),
         Err(e) => Err(e)
     }
 }
