@@ -18,4 +18,6 @@ pub mod httpfetch;
 pub mod jsonfetch;
 pub mod time;
 pub mod metadata;
-pub mod image;
\ No newline at end of file
+pub mod image;
+pub mod diffgif;
+pub mod calprofile;
\ No newline at end of file
