@@ -1,7 +1,17 @@
 
 
-use mars_raw_utils::m20::remote::remote_fetch;
+use mars_raw_utils::m20::{
+    remote,
+    latest
+};
 
+#[test]
+#[ignore]
+fn test_msl_latest() {
+    let latest:latest::LatestData = remote::fetch_latest().expect("Failed to fetch latest data");
+    assert_eq!(latest.latest, "2022-02-19T16:36:39Z");
+    assert_eq!(latest.latest_sols.len(), 3);
+}
 
 #[test]
 #[ignore] // Going to ignore this by default to prevent unneccessary load on NASA's servers
@@ -13,7 +23,7 @@ fn test_m20_instrument_fetches() {
 
     for i in instruments {
         eprintln!("Testing fetch for {}", i);
-        remote_fetch(&vec![String::from(i)], 5, Some(0), 70, 79, false, false, true, "", false).unwrap();
+        remote::remote_fetch(&vec![String::from(i)], 5, Some(0), 70, 79, false, false, true, "", false).unwrap();
     }
 
 }
\ No newline at end of file
